@@ -18,12 +18,12 @@
  *
  */
 #include <string.h>
-#include <ncurses.h>
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include "ap-utils.h"
+#include "ap-curses.h"
 
 extern WINDOW *main_sub;
 
